==> mullet-0.0.18.tgz: package/README.md <==
# The Mullet Stack

[![Join the chat at https://gitter.im/lynnaloo/mullet](https://badges.gitter.im/Join%20Chat.svg)](https://gitter.im/lynnaloo/mullet?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge)

<img src="https://cloud.githubusercontent.com/assets/1610195/5716009/cf500292-9ab1-11e4-84a2-f93f9766afa9.png" align="center" width="200">

[Facebook](http://facebook.github.io/react/) in the front. [Walmart](http://walmartlabs.github.io/hapi/) in the back.

All sitting on top of [Node.js](http://nodejs.org/).

[![NPM version](https://badge.fury.io/js/mullet.svg)](http://badge.fury.io/js/mullet)[![Build Status](https://travis-ci.org/lynnaloo/mullet.svg)](https://travis-ci.org/lynnaloo/mullet)

Get the Party Started
----

Install [Node.js](http://nodejs.org/)

### Setup the Mullet stack for development:
```
git clone https://github.com/lynnaloo/mullet
cd mullet
npm install
```

Start the Mullet Server:
```
npm start
```

Watch the client folders for changes during development:
```
npm run watch
```

#### OR

### Install the Mullet npm module:

```
npm install mullet
```

Start the Mullet Server:
```
npm start mullet
```

Party On!
----

Point your browser to `http://localhost:8000` to see the sample page!

But Seriously
----

This setup is a decent starting place to play around with Node.js, Hapi, and React.js.

To get started, edit the sample React component: `src/react_components/facebook.jsx`

Contributors
----

Mullet Stack was created on a Thursday night by [Linda Nichols](http://www.github.com/lynnaloo). Name inspiration by [Ryan Brunsvold](http://www.github.com/brunsvold) who probably wishes to not be credited on something called "The Mullet Stack."

Mullet Cat Logo design by [Lookmai Rattana](http://www.github.com/cosmicmeow).

Special thanks to all of the people that have taken their time to submit [pull requests](https://github.com/lynnaloo/mullet/graphs/contributors) to make this project better!

Contact
----

Twitter: [@lynnaloo](http://www.twitter.com/lynnaloo)

==> mullet-0.0.19.tgz: package/README.md <==
# The Mullet Stack

[![forthebadge](http://forthebadge.com/images/badges/contains-cat-gifs.svg)](http://forthebadge.com)

<img src="https://cloud.githubusercontent.com/assets/1610195/5716009/cf500292-9ab1-11e4-84a2-f93f9766afa9.png" align="center" width="200">

[Facebook](http://facebook.github.io/react/) in the front. [Walmart](http://walmartlabs.github.io/hapi/) in the back.

All sitting on top of [Node.js](http://nodejs.org/).

[![NPM version](https://badge.fury.io/js/mullet.svg)](http://badge.fury.io/js/mullet) [![Build Status](https://travis-ci.org/lynnaloo/mullet.svg)](https://travis-ci.org/lynnaloo/mullet) [![Join the chat at https://gitter.im/lynnaloo/mullet](https://badges.gitter.im/Join%20Chat.svg)](https://gitter.im/lynnaloo/mullet?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge)

Get the Party Started
----

Install [Node.js](http://nodejs.org/)

### Setup the Mullet stack for development:
```
git clone https://github.com/lynnaloo/mullet
cd mullet
npm install
```

Start the Mullet Server:
```
npm start
```

Watch the client folders for changes during development:
```
npm run watch
```

#### OR

### Install the Mullet npm module:

```
npm install mullet
```

Start the Mullet Server:
```
npm start mullet
```

Party On!
----

Point your browser to `http://localhost:8000` to see the sample page!

But Seriously
----

This setup is a decent starting place to play around with Node.js, Hapi, and React.js.

To get started, edit the sample React component: `src/react_components/facebook.js`

Contributors
----

Mullet Stack was created on a Thursday night by [Linda Nichols](http://www.github.com/lynnaloo). Name inspiration by [Ryan Brunsvold](http://www.github.com/brunsvold) who probably wishes to not be credited on something called "The Mullet Stack."

Mullet Cat Logo design by [Lookmai Rattana](http://www.github.com/cosmicmeow).

Special thanks to all of the people that have taken their time to submit [pull requests](https://github.com/lynnaloo/mullet/graphs/contributors) to make this project better!

Contact
----

Twitter: [@lynnaloo](http://www.twitter.com/lynnaloo)
